/******************************************************************************
 * This is based on the SampleLib example from Palm, which can be downloaded
 * from Palm web site
 *****************************************************************************/

#ifndef __fileprog_LIB_H__
#define __fileprog_LIB_H__


// If we're actually compiling the library code, then we need to
// eliminate the trap glue that would otherwise be generated from
// this header file in order to prevent compiler errors in CW Pro 2.
#ifdef BUILDING_fileprog_LIB
	#define fileprog_LIB_TRAP(trapNum)
#else
	#define fileprog_LIB_TRAP(trapNum) SYS_TRAP(trapNum)
#endif


// Palm OS common definitions
#include <PalmTypes.h>
#include <SystemResources.h>


// Resource: Talt 1000 - these resources belong to FileProg. The library
// doesn't have it's own resources. In case that the library needs specific
// GUI resource and can't reuse any of FileProg resources, please contact
// me and I'll add that resource to FileProg
#define R_FileProgLibAlert                        1000
#define R_FileProgLibOK                           0

/********************************************************************
 * Type and creator of fileprog Library database. FileProg will
 * look for databases in the RAM with creator ID equals to 'AGil'
 * all databases found with this creator ID assumed to be a FileProg
 * plug-in. In order to difrentiate beteen the plug-in's it is possible
 * to use a different database type
 ********************************************************************/
#define		fileprogLibCreatorID	'AGil'	// fileprog Library database creator
#define		fileprogLibTypeID		'libr'	// Standard library database type


/********************************************************************
 * Internal library name which can be passed to SysLibFind()
 ********************************************************************/
#define		fileprogLibName			"FileProg.lib"		


/************************************************************
 * fileprog Library result codes
 * (appErrorClass is reserved for 3rd party apps/libraries.
 * It is defined in SystemMgr.h)
 *************************************************************/

#define fileprogErrParam     (appErrorClass | 1) // invalid parameter
#define fileprogErrNotOpen   (appErrorClass | 2) // library is not open
#define fileprogErrStillOpen (appErrorClass | 3) // returned from fileprogLibClose() if
												 // the library is still open by others
#define fileprogErrMemory    (appErrorClass | 4) // memory error occurred


//-----------------------------------------------------------------------------
// fileprog library function trap ID's. Each library call gets a trap number:
//   fileprogLibTrapXXXX which serves as an index into the library's dispatch table.
//   The constant sysLibTrapCustom is the first available trap number after
//   the system predefined library traps Open,Close,Sleep & Wake.
//
// WARNING!!! The order of these traps MUST match the order of the dispatch
//  table in fileprogLibDispatch.c!!!
//-----------------------------------------------------------------------------

enum 
{
	fileprogLibTrapGetLibAPIVersion = sysLibTrapCustom,
	fileprogLibGetLibDescription,
	fileprogLibRunDbRam,
	fileprogLibRunDbCard,
	fileprogLibProlog,
	fileprogLibEpilog,
	
	fileprogLibTrapLast // must be the last item, used to compute the jump table
};



/********************************************************************
 * Public Structures
 ********************************************************************/
 



/********************************************************************
 * API Prototypes
 ********************************************************************/

#ifdef __cplusplus
extern "C" {
#endif


//--------------------------------------------------
// Standard library open, close, sleep and wake functions
//--------------------------------------------------

extern Err FileprogLibOpen(UInt16 refNum, UInt32 *clientContextP)
				fileprog_LIB_TRAP(sysLibTrapOpen);
				
extern Err FileprogLibClose(UInt16 refNum, UInt32 clientContext)
				fileprog_LIB_TRAP(sysLibTrapClose);

extern Err FileprogLibSleep(UInt16 refNum)
				fileprog_LIB_TRAP(sysLibTrapSleep);

extern Err FileprogLibWake(UInt16 refNum)
				fileprog_LIB_TRAP(sysLibTrapWake);


//--------------------------------------------------
// Custom library API functions. These functions are
// used by FileProg, all of them must be implemented
//--------------------------------------------------
	
// Get our library API version
extern Err FileprogLibGetLibAPIVersion(UInt16 refNum, UInt32 * dwVerP)
				fileprog_LIB_TRAP(fileprogLibTrapGetLibAPIVersion);
	
// Get the library description, this will be presented in the FileProg
// plug-in menu
extern Err FileprogLibGetLibDescription(UInt16 refNum, char* libDecsription)
				fileprog_LIB_TRAP(fileprogLibGetLibDescription);
				
// This function is called for the selected databases, when selecting
// that library on the RAM databases
extern Err FileprogLibRunDbRam(UInt16 refNum, UInt32 clientContext, UInt16 cardNo, LocalID dbID)
				fileprog_LIB_TRAP(fileprogLibRunDbRam);
				
// This function is called when the library operates on card files
extern Err FileprogLibRunDbCard(UInt16 refNum, UInt32 clientContext, UInt16 cardRef, char const *dirPath, char const *fileName)
				fileprog_LIB_TRAP(fileprogLibRunDbCard);

// This function is called before starting going over the list of selected
// files
extern Err FileprogLibProlog(UInt16 refNum, UInt32 clientContext)
				fileprog_LIB_TRAP(fileprogLibProlog);

// This function is called after processing all the selected files. The library
// should set which of the fiole lists should be updated. This is needed if the
// library adds or remove files from the list
extern Err FileprogLibEpilog(UInt16 refNum, UInt32 clientContext, Boolean *refreshRam, Boolean *refreshCard)
				fileprog_LIB_TRAP(fileprogLibEpilog);


// For loading the library in Palm OS Mac emulation mode
extern Err FileprogLibInstall(UInt16 refNum, UInt32 clientContext, SysLibTblEntryPtr entryP);


#ifdef __cplusplus 
}
#endif


/********************************************************************
 * Public Macros
 ********************************************************************/




#endif	// __fileprog_LIB_H__

